/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "../lib/mesh.h"

int main(int argc, char *argv[]) try
{
	std::string dname = "vector-data";

	gctl::regular_grid rgd;
	rgd.init("grid-example", "this grid can store vectors. Yeah!", 15, 10, 0.0, 0.0, 1.0, 1.0);

	gctl::array<gctl::point3dc> init_data(rgd.get_ydim()*rgd.get_xdim());
	for (int j = 0; j < rgd.get_ydim(); j++)
	{
		for (int i = 0; i < rgd.get_xdim(); i++)
		{
			init_data[i + j*rgd.get_xdim()].x = i;
			init_data[i + j*rgd.get_xdim()].y = j;
			init_data[i + j*rgd.get_xdim()].z = i+j;
		}
	}

	gctl::meshdata data = rgd.add_data(gctl::NodeData, dname, init_data);

	rgd.save_binary("sample4-out");

	gctl::regular_grid rgd2;
	rgd2.load_binary("sample4-out");
	rgd2.show_info();
	return 0;
}
catch(std::exception &e)
{
	GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
}